@@ -2,7 +2,7 @@
 
 package Plack::Middleware::HTMLMinify;
 BEGIN {
-  $Plack::Middleware::HTMLMinify::VERSION = '0.3';
+  $Plack::Middleware::HTMLMinify::VERSION = '0.4';
 }
 
 use strict;
@@ -14,7 +14,7 @@ Plack::Middleware::HTMLMinify - Plack middleware for HTML minify
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 DESCRIPTION
 
@@ -52,10 +52,15 @@ sub call {
 	# Don't touch compressed content.
 	return if defined $h->get('Content-Encoding');
 
-	# If response body is undefined then ignore it.
-	return if !defined $res->[2][0];
+	# Concat all content, and if response body is undefined then ignore it.
+	my $body = join '', @{$res->[2]};
+	return if '' eq $body;
+
+	# Minify and replace it.
+	$self->packer->minify(\$body, $self->opt);
+	$res->[2] = [$body];
+	$h->set('Content-Length', length $body);
 
-	$self->packer->minify(\$res->[2][0], $self->opt);
 	return;
     });
 }
